@@ -4,24 +4,42 @@ DataAvailabilityIndex=function(Boundary, Scale, CP,Data){
   }
 
   else if (is(Boundary,"data.frame")){
+    if(nrow(Boundary)>3){
     p = Polygon(Boundary)
     ps = Polygons(list(p),1)
     Boundary = SpatialPolygons(list(ps))
-    proj4string(Boundary) = CP
+    }
+    else{
+      pol = st_polygon(
+        list(
+          cbind(
+            Boundary[,1][c(1,2,2,1,1)],
+            Boundary[,2][c(1,1,2,2,1)])
+        )
+      )
+     }
   }
   else {Boundary=Boundary
-  if(is.na(proj4string(Boundary))) {
-    proj4string(Boundary) = CP}
+  if(is.na(crs(Boundary))) {
+    crs(Boundary)=CP
+    }
   }
-  Boundary=spTransform(Boundary,CRS("+init=epsg:4326"))
+  Boundary=st_as_sfc(Boundary)
+  st_crs(Boundary)=CP
+  Boundary=st_transform(Boundary,4326)
   if(Scale<=0.1){stop("Selected assessment area is too small and must be greater than zero")}
 
-  ext <-  extent (Boundary)
+  Boundary=as(Boundary,"Spatial")
+  crs(Boundary)="+proj=longlat +datum=WGS84 +no_defs"
+  ext <-  extent(Boundary)
   xy <- abs(apply(as.matrix(bbox(ext)), 1, diff))
   if(round(xy[1]/(Scale/111),0)<=1){stop("selected assessment area is too large")}
   w <- raster(ext, ncol=round(xy[1]/(Scale/111),0), nrow=round(xy[2]/(Scale/111),0))
   ww <-rasterize(Boundary, w)
-  Data=spTransform(Data,CRS("+init=epsg:4326"))
+  Data=st_as_sfc(Data,crs=CP)
+  Data = st_transform(Data,4326)
+  Data=as(Data,"Spatial")
+  crs(Data)="+proj=longlat +datum=WGS84 +no_defs"
   pts_in<-Data[!is.na(over(Data,Boundary)),]
 
   pointcount = function(r, pts){
@@ -33,6 +51,6 @@ DataAvailabilityIndex=function(Boundary, Scale, CP,Data){
   }
 
   w2=pointcount(ww,pts_in)
-  proj4string(w2)=CRS("+init=epsg:4326")
+  crs(w2)=CP
   return(w2)
 }
