@@ -1,9 +1,9 @@
 reclassifyMap=function(fgrid,df){
     if(class(fgrid)[1]=="SpatialGridDataFrame"){
     name1=names(fgrid@data[1])
-    ccode=as(fgrid[name1],"RasterLayer")
+    ccode=methods::as(fgrid[name1],"RasterLayer")
     bcode=reclassify(ccode,df)
-    bclass=as(bcode,"SpatialGridDataFrame")
+    bclass=methods::as(bcode,"SpatialGridDataFrame")
     classcode=bclass@data[[1]]
   }
   else{
